import { BusinessData, CreateProposal, Document, UpdateBDIdentification } from '@agiliza/api/domain'
import { extractNumbers } from '@agiliza/utils/extractors'
import { DadosNegocioIdentificacaoApiModel, DocumentoApiModel } from '@microcredito/client'
import { AtualizarIdentificacaoDadosNegocioRequest } from '@microcredito/client/dist/apis/AgenteApi'
import { CriarPropostaRequest } from '@microcredito/client/dist/apis/ClienteApi'

import { ApiAdapter } from '../shared'

export class DocumentApiMapper implements ApiAdapter<Document, DocumentoApiModel> {
  private mapDocumentTypeToApi = (docType: Document['type']): DocumentoApiModel['tipoDocumento'] => ({
    codigo: docType.id,
    descricao: docType.description,
  })

  public mapDomainToApiModel = (doc: Document): DocumentoApiModel => ({
    id: doc.id,
    imagem: doc.url,
    tipoDocumento: this.mapDocumentTypeToApi(doc.type),
    informacoesComplementares: doc.extraInformations,
  })
}

export class BDIdentificationApiMapper implements ApiAdapter<BusinessData['identification'], DadosNegocioIdentificacaoApiModel> {
  private documentAdapter: DocumentApiMapper
  constructor() {
    this.documentAdapter = new DocumentApiMapper()
  }
  public mapDomainToApiModel = (ident: BusinessData['identification']): DadosNegocioIdentificacaoApiModel => ({
    cnpj: extractNumbers(ident?.cnpj),
    codigoCNAE: ident?.codeCNAE,
    dataAbertura: ident?.openingDate !== null ? ident?.openingDate : undefined,
    documento: ident?.document ? this.documentAdapter.mapDomainToApiModel(ident?.document) : undefined,
    inscricaoComercial: ident?.commercialRegistration,
    inscricaoEstadual: ident?.stateRegistration,
    inscricaoMunicipal: ident?.cityRegistration,
    local: ident?.local,
    nomeFantasia: ident?.fantasyName,
    opLiquidada: ident?.settledOP,
    razaoSocial: ident?.companyName,
    setorAtividade: ident?.activitySector,
  })
}

export class BDUpdateIdentificationApiMapper implements ApiAdapter<UpdateBDIdentification['Input'], AtualizarIdentificacaoDadosNegocioRequest> {
  private identificationApiMapper: BDIdentificationApiMapper
  constructor() {
    this.identificationApiMapper = new BDIdentificationApiMapper()
  }
  public mapDomainToApiModel = (input: UpdateBDIdentification['Input']): AtualizarIdentificacaoDadosNegocioRequest => ({
    projetoId: input.projectId,
    dadosNegocioIdentificacaoApiModel: this.identificationApiMapper.mapDomainToApiModel(input.identification),
  })
}

export class CreateProposalApiMapper implements ApiAdapter<CreateProposal['Input'], CriarPropostaRequest> {
  public mapDomainToApiModel = (input: CreateProposal['Input']): CriarPropostaRequest => ({
    criarPropostaRequestApiModel: {
      carencia: input.gracePeriodId,
      categoriaSimulacao: input.categoryId,
      quantidadeParcelas: input.installmentsNumber,
      valorInteresse: input.creditValue,
      subprodutoId: input.subproductId,
    },
  })
}
