import { BDIdentification, Document } from '@agiliza/api/domain'
import { DadosNegocioIdentificacaoApiModel, DocumentoApiModel } from '@microcredito/client'

import { DomainAdapter } from '../shared'

export class ProjectDocumentMapper implements DomainAdapter<DocumentoApiModel, Document> {
  public mapTipoDocumentoApiToDomain = (tipo: DocumentoApiModel['tipoDocumento']): Document['type'] => ({
    id: tipo.codigo,
    description: tipo.descricao,
  })
  public mapApiModelToDomain = (apimodel: DocumentoApiModel): Document => ({
    id: apimodel.id,
    url: apimodel.imagem,
    type: this.mapTipoDocumentoApiToDomain(apimodel.tipoDocumento),
    extraInformations: apimodel.informacoesComplementares || '',
  })
}

export class BDIdentificationMapper implements DomainAdapter<DadosNegocioIdentificacaoApiModel, BDIdentification> {
  private documentAdapter: ProjectDocumentMapper

  constructor() {
    this.documentAdapter = new ProjectDocumentMapper()
  }
  public mapApiModelToDomain = (dnIdent: DadosNegocioIdentificacaoApiModel): BDIdentification => ({
    activitySector: dnIdent.setorAtividade || '',
    cityRegistration: dnIdent.inscricaoMunicipal || '',
    cnpj: dnIdent.cnpj || '',
    codeCNAE: dnIdent.codigoCNAE || '',
    commercialRegistration: dnIdent.inscricaoComercial || '',
    companyName: dnIdent.razaoSocial || '',
    fantasyName: dnIdent.nomeFantasia || '',
    local: dnIdent.local || '',
    openingDate: dnIdent.dataAbertura || null,
    settledOP: dnIdent.opLiquidada || '',
    stateRegistration: dnIdent.inscricaoEstadual || '',
    document: dnIdent.documento ? this.documentAdapter.mapApiModelToDomain(dnIdent.documento) : undefined,
  })
}
