import { GetSubProducts } from '@agiliza/api/domain/simulation/simulation'
import { Configuration } from '@microcredito/client'
import { AnonimoApi } from '@microcredito/client/dist/apis/AnonimoApi'

import { ErrorMappers, SimulationApiMappers, SimulationMappers } from '../../mappers'
import { API_URL, mapUserAgentToString, UserAgent } from '../shared'

export interface SimulationRepository {
  getSubproducts(input: GetSubProducts['Input']): Promise<GetSubProducts['Output']>
}

export class SimulationRepositoryImpl implements SimulationRepository {
  private api: AnonimoApi
  private getSubproductsApiMapper: SimulationApiMappers.GetSubProductsApiMapper
  private subproductMapper: SimulationMappers.SubProductMapper
  private errorAdapter: ErrorMappers.ResponseErrorAdapter

  constructor(userAgent: string) {
    this.errorAdapter = new ErrorMappers.ResponseErrorAdapter()
    this.getSubproductsApiMapper = new SimulationApiMappers.GetSubProductsApiMapper()
    this.subproductMapper = new SimulationMappers.SubProductMapper()
    this.api = new AnonimoApi(
      new Configuration({
        basePath: API_URL,
        headers: {
          'User-Agent': userAgent,
        },
      })
    )
  }

  public getSubproducts = async (input: GetSubProducts['Input']): Promise<GetSubProducts['Output']> => {
    try {
      const result = await this.api.anonimoObterSubprodutos({
        simularCreditoRequestApiModel: this.getSubproductsApiMapper.mapDomainToApiModel(input),
      })
      return result.map(this.subproductMapper.mapApiModelToDomain)
    } catch (e) {
      const result = await this.errorAdapter.mapApiModelToDomain(e)
      throw result
    }
  }
}

export class SimulationRepositoryImplFactory {
  static create(userAgent: UserAgent) {
    const repository = new SimulationRepositoryImpl(mapUserAgentToString(userAgent))
    return repository
  }
}
