import React from 'react'

import { BanestesAccount } from '@agiliza/api/domain'
import { Button, TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import { PhotoCamera as PhotoCameraIcon } from '@material-ui/icons'

import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  values: BanestesAccount
  onChanges: {
    account: (type: keyof BanestesAccount) => TextFieldProps['onChange']
    photo: (name: string) => void
    validState?: (validState: boolean) => void
  }
}

const AccountInputsPhoto = (props: Props) => {
  const { classes, values, onChanges } = props
  const { agencyNumber, cardPicture, number } = values

  const handleChangeField = (type: keyof BanestesAccount): TextFieldProps['onChange'] => onChanges.account(type)

  const handleChangePhoto: React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>['onChange'] = (evt) => {
    const file = evt.target.files && evt.target.files[0]
    if (file) onChanges.photo(URL.createObjectURL(file))
  }

  return (
    <div className={classes.accountInputsPhotoContainer}>
      <div className={classes.accountInputsContainer}>
        <TextField label="Número da agência" value={agencyNumber || ''} onChange={handleChangeField('agencyNumber')} variant="outlined" />
        <TextField label="Número da conta corrente" value={number || ''} onChange={handleChangeField('number')} variant="outlined" />
      </div>
      <Button variant="text" component="label" className={classes.photoBtn} classes={{ label: classes.photoLabelBtn }}>
        {cardPicture ? (
          <div className={classes.card}>
            <img src={cardPicture} className={classes.media} />
          </div>
        ) : (
          <PhotoCameraIcon />
        )}
        Foto cartão
        <input
          type="file"
          // value={cardPicture}
          accept="image/jpg, image/jpeg, image/png"
          hidden
          onChange={handleChangePhoto}
        />
      </Button>
    </div>
  )
}

export default withStyles(styles)(AccountInputsPhoto)
