import React, { useMemo } from 'react'

import { City, State } from '@agiliza/api/domain'
import { ActionType } from '@agiliza/utils/hooks/state'
import { maskCEP } from '@agiliza/utils/masks'
import { SelectField, SelectFieldProps } from '@curio/components'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { AddressState as FormState } from './state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  states: State[]
  cities: City[]
  state: FormState
  actions: ActionType<FormState>
}

const Address = (props: Props) => {
  const { classes, state: _state, actions, states, cities } = props

  const { cep, street, number, complement, state, city, district } = _state

  const handleChange =
    (key: keyof FormState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  const handleChangeSelect =
    (key: keyof FormState): SelectFieldProps['onChange'] =>
    (value) => {
      actions.update({ [key]: value })
    }

  const availableCities = useMemo(() => {
    if (state === '') return []
    return cities.filter((ct) => ct.state === state)
  }, [state])

  return (
    <>
      <TextField variant="outlined" label="CEP" value={maskCEP(cep)} onChange={handleChange('cep')} inputProps={{ maxLength: 9 }} />
      <TextField variant="outlined" label="Rua / Avenida" value={street} onChange={handleChange('street')} />
      <TextField variant="outlined" label="Número" value={number} onChange={handleChange('number')} />
      <TextField variant="outlined" label="Complemento" value={complement} onChange={handleChange('complement')} />
      <SelectField
        id="state-select"
        variant="outlined"
        label="Estado"
        value={state}
        onChange={handleChangeSelect('state')}
        items={states.map((st) => ({ label: st.name, value: st.id }))}
        shrink={false}
        className={classes.selectField}
      />
      <SelectField
        id="state-select"
        variant="outlined"
        disabled={!state}
        label="Cidade"
        value={city}
        onChange={handleChangeSelect('city')}
        items={availableCities.map((st) => ({ label: st.name, value: st.id }))}
        shrink={false}
        className={classes.selectField}
      />
      <TextField variant="outlined" label="Bairro" value={district} onChange={handleChange('district')} />
    </>
  )
}

export default withStyles(styles)(Address)
