import React from 'react'

import { City, State } from '@agiliza/api/domain/authentication'
import { getErrorProps, useErrorValidator } from '@agiliza/utils/hooks/errorValidation'
import { ActionType } from '@agiliza/utils/hooks/state'
import { maskCPFCNPJ, maskPhone } from '@agiliza/utils/masks'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import AddressForm from '../Address'
import { initState, State as FirstAccessState } from './state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  states: State[]
  cities: City[]
  state: FirstAccessState
  actions: ActionType<FirstAccessState>
}

const FirstAccess = (props: Props) => {
  const { classes, states, cities, state, actions } = props

  const { cpf, name, email, phone, ...addressState } = state

  const { errorState, actions: errorActions } = useErrorValidator(initState)

  const handleChange =
    (key: keyof FirstAccessState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
      errorActions.validate({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField
        variant="outlined"
        label="CPF"
        value={maskCPFCNPJ(cpf)}
        onChange={handleChange('cpf')}
        inputProps={{ maxLength: 14 }}
        disabled
        {...getErrorProps(errorState.cpf)}
      />
      <TextField variant="outlined" label="Nome" value={name} onChange={handleChange('name')} />
      <TextField variant="outlined" label="Email" value={email} onChange={handleChange('email')} />
      <TextField variant="outlined" label="Telefone" value={maskPhone(phone)} onChange={handleChange('phone')} inputProps={{ maxLength: 15 }} />
      <AddressForm state={addressState} actions={actions} states={states} cities={cities} />
    </form>
  )
}

export default withStyles(styles)(FirstAccess)
