import { CreateProposal } from '@agiliza/api/domain'
import {
  PDCustomerDataRepositoryImplFactory
} from '@agiliza/api/useCases/proposalData/customerData'
import { appPlatform } from '@agiliza/constants/platform'
import {
  createAsyncReducers,
  getTypesThunkActions,
  values,
  WithSuccess
} from '@agiliza/utils/method'
import { createAsyncThunk, createSlice } from '@reduxjs/toolkit'

const prefix = 'useCases/customerData'

export interface State {
  fetching: boolean
}

export const initialState: State = {
  fetching: false,
}

export const actions = {
  createProposal: createAsyncThunk(`${prefix}/createProposal`, async (input: WithSuccess<CreateProposal['Input']>, thunkApi) => {
    const useCase = PDCustomerDataRepositoryImplFactory.create(appPlatform)
    try {
      const proposalId = await useCase.createProposal(input)
      input.onSuccess && input.onSuccess()
      return proposalId
    } catch (e) {
      return thunkApi.rejectWithValue(e)
    }
  }),
  updateIndentification: createAsyncThunk(`${prefix}/updateIndentification`, async (input: WithSuccess<CreateProposal['Input']>, thunkApi) => {
    const useCase = PDCustomerDataRepositoryImplFactory.create(appPlatform)
    try {
      const proposalId = await useCase.createProposal(input)
      input.onSuccess && input.onSuccess()
      return proposalId
    } catch (e) {
      return thunkApi.rejectWithValue(e)
    }
  }),
} as const
export const types = getTypesThunkActions(actions)

const login = createSlice({
  name: prefix,
  initialState,
  reducers: {},
  extraReducers: {
    ...values(types).reduce((reducers, type) => ({ ...reducers, ...createAsyncReducers(type) }), {}),
  },
})

export default login
