import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import Address from '@agiliza/views/ProposalData/components/templates/Address'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { BDAddressState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: BDAddressState
  actions: ActionType<BDAddressState>
}

const Form = (props: Props) => {
  const { classes, state: _state, actions } = props

  const { cep, number, street, city, complement, district, state, referencePoint } = _state

  const handleChangeText =
    (key: keyof BDAddressState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <Address state={{ cep, number, street, city, complement, district, state }} onChange={(addrs) => actions.update(addrs)} />
      <TextField variant="outlined" label="Ponto de referência" value={referencePoint} onChange={handleChangeText('referencePoint')} />
    </form>
  )
}

export default withStyles(styles)(Form)
