import React, { ChangeEvent, useState } from 'react'
import { RouteComponentProps } from 'react-router'

import { Tab } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import {
  AccountBox as AccountBoxIcon,
  Apartment as ApartmentIcon,
  AttachMoney as AttachMoneyIcon,
  InsertDriveFile as InsertDriveFileIcon
} from '@material-ui/icons'
import { TabContext, TabList, TabPanel } from '@material-ui/lab'

import Address from './Address'
import Identification from './Identification'
import ProductsServices from './ProductsServices'
import StockSalesCosts from './StockSalesCosts'
import styles from './styles'

export const businessDataItems = [
  { label: 'Identificação', icon: <AccountBoxIcon />, component: <Identification /> },
  { label: 'Endereço', icon: <ApartmentIcon />, component: <Address /> },
  { label: 'Estoque, Vendas e Custos', icon: <AttachMoneyIcon />, component: <StockSalesCosts /> },
  { label: 'Produto', icon: <InsertDriveFileIcon />, component: <ProductsServices /> },
]

type ExtendedProps = WithStyles<typeof styles> & RouteComponentProps

interface Props extends ExtendedProps {}

const BusinessData = (props: Props) => {
  const { classes } = props
  const [tab, setTab] = useState('0')

  const handleChange = (evt: ChangeEvent<Record<string, unknown>>, newValue: number) => {
    setTab(newValue.toString())
  }

  return (
    <div className={classes.contentContainer}>
      {/* <div className={classes.breadcrumbsContainer}>
        <Breadcrumbs aria-label="breadcrumb">
          <Link color="inherit" href="/" onClick={() => history.push(PATHS.proposalData)}>
            Dados Proposta
          </Link>
          <Link href="/" color="textPrimary" onClick={() => history.push(PATHS.proposalData + PROPOSAL_DATA_PATHS.businessData)}>
            Dados Negócio
          </Link>
        </Breadcrumbs>
      </div> */}
      <div className={classes.tabsContainer}>
        <TabContext value={tab}>
          <TabList
            orientation="vertical"
            variant="scrollable"
            value={tab}
            onChange={handleChange}
            aria-label="Vertical tabs example"
            className={classes.tabs}
          >
            {businessDataItems.map(({ component, ...tb }, i) => (
              <Tab wrapped key={i} {...tb} value={i.toString()} />
            ))}
          </TabList>
          <div className={classes.content}>
            {businessDataItems.map((tb, i) => (
              <TabPanel key={i} value={i.toString()}>
                {tb.component}
              </TabPanel>
            ))}
          </div>
        </TabContext>
      </div>
    </div>
  )
}

export default withStyles(styles)(BusinessData)
