import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskCPFCNPJ } from '@agiliza/utils/masks'
import { DatePicker } from '@curio/components'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { BDIdentificationState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: BDIdentificationState
  actions: ActionType<BDIdentificationState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { cnpj, openingDate } = state

  const handleChangeText =
    (key: keyof BDIdentificationState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  const handleChangeDate = (type: keyof Pick<BDIdentificationState, 'openingDate'>) => (date: Date | null) => {
    actions.update({ [type]: date })
  }

  return (
    <form className={classes.form}>
      <TextField
        variant="outlined"
        type="tel"
        label="CNPJ"
        value={maskCPFCNPJ(cnpj)}
        onChange={handleChangeText('cnpj')}
        inputProps={{ maxLength: 18 }}
      />
      <DatePicker
        id="admission-date"
        label="Data de admissão"
        value={openingDate}
        onChange={handleChangeDate('openingDate')}
        format="dd/MM/yyyy"
        className={classes.datePicker}
      />
    </form>
  )
}

export default withStyles(styles)(Form)
