import React, { useEffect } from 'react'

import { BDProductService } from '@agiliza/api/domain'
import { useFormState } from '@agiliza/utils/hooks/state'
import {
  Button,
  Dialog as MUIDialog,
  DialogActions,
  DialogContent,
  DialogProps,
  DialogTitle
} from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import Form from '../Form'
import { initialState } from '../state'
import styles from './styles'

type ExtendedProps = Pick<DialogProps, 'open'> & WithStyles<typeof styles>

interface Props extends ExtendedProps {
  onClose: () => void
  productService?: BDProductService
  onSave(rfc: BDProductService): () => void
}

const Dialog = (props: Props) => {
  const { classes, open, onClose, onSave, productService } = props

  const formState = useFormState('VehicleForm', initialState)

  const { actions } = formState

  useEffect(() => {
    if (productService) actions.update(productService)
    else actions.update(initialState)
  }, [productService])

  const mapStateToProductService = (): BDProductService => {
    return formState.state
  }

  return (
    <MUIDialog onClose={onClose} aria-labelledby="simple-dialog-title" open={open} PaperProps={{ className: classes.dialog }}>
      <DialogTitle>{productService ? 'Editar' : 'Adicionar'} pessoa envolvida</DialogTitle>
      <DialogContent>
        <Form {...formState} />
      </DialogContent>
      <DialogActions>
        <Button onClick={onClose}>Cancelar</Button>
        <Button onClick={onSave(mapStateToProductService())}>Salvar</Button>
      </DialogActions>
    </MUIDialog>
  )
}

export default withStyles(styles)(Dialog)
