import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { BDProductServiceState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: BDProductServiceState
  actions: ActionType<BDProductServiceState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { description, unit } = state

  const handleChangeText =
    (key: keyof BDProductServiceState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="Descrição do produto / serviço" value={description} onChange={handleChangeText('description')} />
      <TextField variant="outlined" label="Placa" value={unit} onChange={handleChangeText('unit')} type="tel" />
    </form>
  )
}

export default withStyles(styles)(Form)
