import React, { useState } from 'react'

import { productServices } from '@agiliza/__mocks__/proposalData/involvedPeople/productServices'
import { BDProductService } from '@agiliza/api/domain'
import { Avatar, List, ListItem, ListItemAvatar, ListItemText } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import { Add as AddIcon, Apps as AppsIcon } from '@material-ui/icons'

import Dialog from './Dialog'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {}

const ProductsServices = (props: Props) => {
  const { classes } = props

  const [selectedProductService, setSelectedProductService] = useState<BDProductService | undefined>()

  const [open, setOpen] = useState(false)

  const handleClickListItem = (vehicle: BDProductService) => () => {
    setSelectedProductService(vehicle)
    setOpen(true)
  }

  const handleClickAdd = () => {
    setOpen(true)
    setSelectedProductService(undefined)
  }

  const handleSave = (vehicle: BDProductService) => () => {}

  return (
    <>
      <div className={classes.contentContainer}>
        <div className={classes.content}>
          <List className={classes.list}>
            {productServices.map((vehicle, i) => (
              <ListItem key={i} button onClick={handleClickListItem(vehicle)}>
                <ListItemAvatar>
                  <Avatar>
                    <AppsIcon />
                  </Avatar>
                </ListItemAvatar>
                <ListItemText primary={vehicle.description} />
              </ListItem>
            ))}
          </List>
        </div>
      </div>
      <Avatar className={classes.avatarBtnContainer} onClick={handleClickAdd}>
        <AddIcon />
      </Avatar>
      <Dialog open={open} onClose={() => setOpen(false)} productService={selectedProductService} onSave={handleSave} />
    </>
  )
}

export default withStyles(styles)(ProductsServices)
