import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskMonthYear } from '@agiliza/utils/masks'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { BDStockSalesCostsState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: BDStockSalesCostsState
  actions: ActionType<BDStockSalesCostsState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { monthYearReference, salesCommission } = state

  const handleChangeText =
    (key: keyof BDStockSalesCostsState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField
        variant="outlined"
        label="Mês/Ano referência"
        value={maskMonthYear(monthYearReference)}
        onChange={handleChangeText('monthYearReference')}
        inputProps={{ maxLength: 7 }}
        type="tel"
      />
      <TextField
        variant="outlined"
        label="Comissão vendas (%)"
        value={salesCommission}
        onChange={handleChangeText('salesCommission')}
        inputProps={{ maxLength: 7 }}
      />
    </form>
  )
}

export default withStyles(styles)(Form)
