import React from 'react'

import { IPAddress } from '@agiliza/api/domain'
import { ActionType } from '@agiliza/utils/hooks/state'
import AddressTemplate from '@agiliza/views/ProposalData/components/templates/Address'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerHomeState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerHomeState
  actions: ActionType<CustomerHomeState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { resideTime, cityResideTime, address } = state

  const handleChangeText =
    (key: keyof CustomerHomeState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="Tempo (no local)" value={resideTime} onChange={handleChangeText('resideTime')} type="number" />
      <TextField variant="outlined" label="Tempo (no município)" value={cityResideTime} onChange={handleChangeText('cityResideTime')} type="number" />
      <AddressTemplate state={address} onChange={(addrs) => actions.update({ address: addrs as IPAddress })} />
    </form>
  )
}

export default withStyles(styles)(Form)
