import { connect } from 'react-redux'
import { bindActionCreators, Dispatch } from 'redux'

import { ProposalDataContext } from '@agiliza/api/domain'
import { StoreState } from '@agiliza/redux'
import * as entProposalDataContext from '@agiliza/redux/entities/proposalData/context'
import * as ucProposalDataContext from '@agiliza/redux/useCases/proposalData/context'
import * as ucProposalDataCD from '@agiliza/redux/useCases/proposalData/customerData'

export interface ConnectedProps {
  fetching: boolean
  context: ProposalDataContext
  fetchContext: typeof ucProposalDataContext.actions.fetchContext
  updateIndentification: typeof ucProposalDataCD.actions.updateIndentification
}

type StateProps = Pick<ConnectedProps, 'fetching' | 'context'>
type DispatchProps = Pick<ConnectedProps, 'fetchContext' | 'updateIndentification'>

const mapStateToProps = (state: StoreState): StateProps => ({
  fetching: ucProposalDataContext.selectors.isFetching(state.ui.login),
  context: entProposalDataContext.selectors.getContext(state.entities.proposalData.context),
})

const mapDispatchToProps = (dispatch: Dispatch): DispatchProps =>
  bindActionCreators(
    {
      fetchContext: ucProposalDataContext.actions.fetchContext,
      updateIndentification: ucProposalDataCD.actions.updateIndentification,
    },
    dispatch
  )

export const connected = connect(mapStateToProps, mapDispatchToProps)
