import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { DatePicker } from '@curio/components'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerPersonalDataState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerPersonalDataState
  actions: ActionType<CustomerPersonalDataState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { birthday, primaryEmail } = state

  const handleChangeDate = (type: keyof Pick<CustomerPersonalDataState, 'birthday'>) => (date: Date | null) => {
    actions.update({ [type]: date })
  }

  const handleChangeText =
    (key: keyof CustomerPersonalDataState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <DatePicker
        id="birthday"
        label="Data de nascimento"
        value={birthday}
        onChange={handleChangeDate('birthday')}
        format="dd/MM/yyyy"
        className={classes.datePicker}
      />
      <TextField variant="outlined" label="Email primário" value={primaryEmail} onChange={handleChangeText('primaryEmail')} />
    </form>
  )
}

export default withStyles(styles)(Form)
