import React, { useEffect } from 'react'

import { Reference } from '@agiliza/api/domain'
import { useFormState } from '@agiliza/utils/hooks/state'
import {
  Button,
  Dialog as MUIDialog,
  DialogActions,
  DialogContent,
  DialogProps,
  DialogTitle
} from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import Form from '../Form'
import { initialState } from '../state'
import styles from './styles'

type ExtendedProps = Pick<DialogProps, 'open'> & WithStyles<typeof styles>

interface Props extends ExtendedProps {
  onClose: () => void
  reference?: Reference
  onSave(rfc: Reference): () => void
}

const Dialog = (props: Props) => {
  const { classes, open, onClose, onSave, reference } = props

  const formState = useFormState('referenceForm', initialState)

  const { actions } = formState

  useEffect(() => {
    if (reference) actions.update(reference)
    else actions.update(initialState)
  }, [reference])

  const mapStateToReference = (): Reference => {
    return formState.state
  }

  return (
    <MUIDialog onClose={onClose} aria-labelledby="simple-dialog-title" open={open} PaperProps={{ className: classes.dialog }}>
      <DialogTitle>{reference ? 'Editar' : 'Adicionar'} pessoa envolvida</DialogTitle>
      <DialogContent>
        <Form {...formState} />
      </DialogContent>
      <DialogActions>
        <Button onClick={onClose}>Cancelar</Button>
        <Button onClick={onSave(mapStateToReference())}>Salvar</Button>
      </DialogActions>
    </MUIDialog>
  )
}

export default withStyles(styles)(Dialog)
