import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskPhone } from '@agiliza/utils/masks'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerReferenceState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerReferenceState
  actions: ActionType<CustomerReferenceState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { name, telephone } = state

  const handleChangeText =
    (key: keyof CustomerReferenceState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="Nome" value={name} onChange={handleChangeText('name')} />
      <TextField
        variant="outlined"
        label="Telefone"
        value={maskPhone(telephone)}
        onChange={handleChangeText('telephone')}
        inputProps={{ maxLength: 15 }}
      />
    </form>
  )
}

export default withStyles(styles)(Form)
