import React, { useState } from 'react'

import { references } from '@agiliza/__mocks__/proposalData'
import { Reference } from '@agiliza/api/domain/proposalData/involvedPeople/reference'
import { Avatar, List, ListItem, ListItemAvatar, ListItemText } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import { Add as AddIcon, EmojiEmotions as EmojiEmotionsIcon } from '@material-ui/icons'

import Dialog from './Dialog'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {}

const References = (props: Props) => {
  const { classes } = props

  const [selectedReference, setSelectedReference] = useState<Reference | undefined>()

  const [open, setOpen] = useState(false)

  const handleClickListItem = (reference: Reference) => () => {
    setSelectedReference(reference)
    setOpen(true)
  }

  const handleClickAdd = () => {
    setOpen(true)
    setSelectedReference(undefined)
  }

  const handleSave = (reference: Reference) => () => {}

  return (
    <>
      <div className={classes.contentContainer}>
        <div className={classes.content}>
          <List className={classes.list}>
            {references.map((reference, i) => (
              <ListItem key={i} button onClick={handleClickListItem(reference)}>
                <ListItemAvatar>
                  <Avatar>
                    <EmojiEmotionsIcon />
                  </Avatar>
                </ListItemAvatar>
                <ListItemText primary={reference.name} secondary={reference.extraInfo} />
              </ListItem>
            ))}
          </List>
        </div>
      </div>
      <Avatar className={classes.avatarBtnContainer} onClick={handleClickAdd}>
        <AddIcon />
      </Avatar>
      <Dialog open={open} onClose={() => setOpen(false)} reference={selectedReference} onSave={handleSave} />
    </>
  )
}

export default withStyles(styles)(References)
