import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskCPFCNPJ } from '@agiliza/utils/masks'
import { DatePicker } from '@curio/components'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerSourceIncomeState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerSourceIncomeState
  actions: ActionType<CustomerSourceIncomeState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { cnpj, admissionDate } = state

  const handleChangeDate = (type: keyof Pick<CustomerSourceIncomeState, 'admissionDate'>) => (date: Date | null) => {
    actions.update({ [type]: date })
  }

  const handleChangeText =
    (key: keyof CustomerSourceIncomeState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="CNPJ" value={maskCPFCNPJ(cnpj)} onChange={handleChangeText('cnpj')} />
      <DatePicker
        id="admission-date"
        label="Data de admissão"
        value={admissionDate}
        onChange={handleChangeDate('admissionDate')}
        format="dd/MM/yyyy"
        className={classes.datePicker}
      />
    </form>
  )
}

export default withStyles(styles)(Form)
