import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskPhone } from '@agiliza/utils/masks'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerSpousePersonalDataState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerSpousePersonalDataState
  actions: ActionType<CustomerSpousePersonalDataState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { mobile, primaryEmail } = state

  const handleChangeText =
    (key: keyof CustomerSpousePersonalDataState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="Telefone celular" value={maskPhone(mobile)} onChange={handleChangeText('mobile')} />
      <TextField variant="outlined" label="Email primário" value={primaryEmail} onChange={handleChangeText('primaryEmail')} />
    </form>
  )
}

export default withStyles(styles)(Form)
