import React from 'react'

import { ActionType } from '@agiliza/utils/hooks/state'
import { maskLicensePlate } from '@agiliza/utils/masks'
import { TextField, TextFieldProps } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'

import { CustomerVehicleState } from '../state'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {
  state: CustomerVehicleState
  actions: ActionType<CustomerVehicleState>
}

const Form = (props: Props) => {
  const { classes, state, actions } = props

  const { brand, licensePlate } = state

  const handleChangeText =
    (key: keyof CustomerVehicleState): TextFieldProps['onChange'] =>
    (evt) => {
      actions.update({ [key]: evt.target.value })
    }

  return (
    <form className={classes.form}>
      <TextField variant="outlined" label="Marca" value={brand} onChange={handleChangeText('brand')} />
      <TextField
        variant="outlined"
        label="Placa"
        value={maskLicensePlate(licensePlate)}
        onChange={handleChangeText('licensePlate')}
        inputProps={{ maxLength: 8 }}
      />
    </form>
  )
}

export default withStyles(styles)(Form)
