import React, { useState } from 'react'

import { vehicles } from '@agiliza/__mocks__/proposalData'
import { Vehicle } from '@agiliza/api/domain'
import { Avatar, List, ListItem, ListItemAvatar, ListItemText } from '@material-ui/core'
import { withStyles, WithStyles } from '@material-ui/core/styles'
import { Add as AddIcon, DriveEta as DriveEtaIcon } from '@material-ui/icons'

import Dialog from './Dialog'
import styles from './styles'

type ExtendedProps = WithStyles<typeof styles>

interface Props extends ExtendedProps {}

const Vehicles = (props: Props) => {
  const { classes } = props

  const [selectedVehicle, setSelectedVehicle] = useState<Vehicle | undefined>()

  const [open, setOpen] = useState(false)

  const handleClickListItem = (vehicle: Vehicle) => () => {
    setSelectedVehicle(vehicle)
    setOpen(true)
  }

  const handleClickAdd = () => {
    setOpen(true)
    setSelectedVehicle(undefined)
  }

  const handleSave = (vehicle: Vehicle) => () => {}

  return (
    <>
      <div className={classes.contentContainer}>
        <div className={classes.content}>
          <List className={classes.list}>
            {vehicles.map((vehicle, i) => (
              <ListItem key={i} button onClick={handleClickListItem(vehicle)}>
                <ListItemAvatar>
                  <Avatar>
                    <DriveEtaIcon />
                  </Avatar>
                </ListItemAvatar>
                <ListItemText primary={vehicle.brand} secondary={vehicle.licensePlate} />
              </ListItem>
            ))}
          </List>
        </div>
      </div>
      <Avatar className={classes.avatarBtnContainer} onClick={handleClickAdd}>
        <AddIcon />
      </Avatar>
      <Dialog open={open} onClose={() => setOpen(false)} vehicle={selectedVehicle} onSave={handleSave} />
    </>
  )
}

export default withStyles(styles)(Vehicles)
